#!/bin/sh
# Install postgresql-9.1
#
#
# Some checkings before installing

trap "on_error; on_exit; exit" INT QUIT TERM

source /usr/local/bin/functions.sh
source ./application_checks.sh
source ./packages_template.sh
source ./user.sh
source ./web.sh
source ./postgresql.sh

app="innovaphone-faxserver"

installed_packages=""
cfg_tmp_dir=""
config_pg_dir=""
config_pg_file=""
innovaphone_user=""
innovaphone_group=""
database_user=""
database_name=""
faxserver_tmp=""
cron_table=""
username=""
groupname=""

function on_exit() {
    if [ -n "$cfg_tmp_dir" ]; then
        rm -rf $cfg_tmp_dir
    fi
    if [ -n "$faxserver_tmp" ]; then
        rm -rf $faxserver_tmp
    fi
    apt-get clean
    if [ -f /etc/init.d/innovaphone-faxserver ]; then
        sleep 5s
        /etc/init.d/innovaphone-faxserver start
    fi
} 

function on_error() {
    # drop database
    if [ -n "$database_name" ]; then
        sudo -u postgres dropdb $database_name
    fi
    # drop database user
    if [ -n "$database_user" ]; then
        sudo -u postgres psql -c "DROP USER ${database_user}" postgres 2>/dev/null
    fi
    # uninstall packages
    if [ -n "$installed_packages" ]; then
        apt-get -y --force-yes purge $installed_packages 
	    apt-get autoremove
    fi
    # linux-user
    if [ -n "$innovaphone_user" ]; then
        deluser $innovaphone_user 2>/dev/null
    fi
    if [ -n "$innovaphone_group" ]; then
        delgroup $innovaphone_group 2>/dev/null
    fi
    if [ -n "$cfg_tmp_dir" -a -n "$config_pg_dir" ]; then
        cp $cfg_tmp_dir/postgresql.conf $config_pg_dir 2>/dev/null
        cp $cfg_tmp_dir/pg_hba.conf $config_pg_dir 2>/dev/null
    fi
    if [ -f /etc/init.d/innovaphone-faxserver ]; then
        /etc/init.d/innovaphone-faxserver stop
        update-rc.d -f innovaphone-faxserver remove
        rm -f /etc/init.d/innovaphone-faxserver
    fi
    on_exit
}

# check application, hotfix, version etc.
check_application ${app}

if [ ! -d /tmp ]; then
    log_msg "Directory tmp does not exists, create"
    mkdir /tmp
    chmod 777 /tmp
    chmod a+t /tmp    
fi

# Keep the config files that will be modified in case something goes wrong...
cfg_tmp_dir=`mktemp -d /tmp/config.$$.XXXX`
if [ $? -ne 0 ]; then
    echo "ERROR: $(date '+%Y-%m-%d %H:%M:%S') - Can't create temp config file, exiting..."
    on_error
    exit 1
fi
chmod 777 $cfg_tmp_dir

install_packages install "unoconv libreoffice-writer libreoffice-draw ghostscript sfftobmp libtiff-tools tnef"
if [ $? -ne 0 ]; then
    exit 1
fi

# call create_user function of user.sh
create_user ${app}

# call postgresql function of postgresql.sh
postgresql ${app} $cfg_tmp_dir faxserver_database.psql faxserver

faxserver_conf=/home/innovaphone-faxserver/faxserver.conf
touch $faxserver_conf
echo '<?xml version="1.0" encoding="utf-8"?>' > $faxserver_conf
echo '<config>' >> $faxserver_conf
echo '</config>' >> $faxserver_conf
chmod 770 $faxserver_conf
chown ${app}:${app} $faxserver_conf

log_msg "Install faxserver files"

install_web ${app} "web/${app}"

uninstall=/home/${app}/uninstall.sh
mv uninstall.sh $uninstall
chmod 755 $uninstall
chown www-data:www-data $uninstall

# Install faxserver cleanup cron job
cron_table="/etc/cron.d/faxserver_cleanup"
script_folder="/usr/local/bin/"
cleanup_script="faxserver_cleanup.sh"
cleanup_log="/var/www/innovaphone/apps/${app}/log/faxserver_cleanup.log"
if [ -f $cleanup_script ]; then
    chown ${app}:www-data ${cleanup_script}
    chmod 700 ${cleanup_script}
    mv ${cleanup_script} ${script_folder}
else
    echo "ERROR: $(date '+%Y-%m-%d %H:%M:%S') - ${cleanup_script} not available"
    on_error
    exit 1
fi
if grep $cleanup_script < $cron_table 1>/dev/null
then
    echo "$(date '+%Y-%m-%d %H:%M:%S') - faxserver cleanup script already in crontab"
else
    echo "$(date '+%Y-%m-%d %H:%M:%S') - inserting faxserver cleanup script to crontab"
    echo "PATH=/usr/local/sbin:/usr/local/bin:/sbin:/bin:/usr/sbin:/usr/bin" >> ${cron_table}
    echo "0 1 * * * root [ -x ${script_folder}${cleanup_script} ] && nice -1 ${script_folder}${cleanup_script} ${cleanup_log} >> ${cleanup_log} 2>&1" >> ${cron_table}
fi
cron_table2="/etc/cron.d/faxserver_check"
initdscript="/etc/init.d/${app}"
echo "PATH=/usr/local/sbin:/usr/local/bin:/sbin:/bin:/usr/sbin:/usr/bin" >> ${cron_table2}
echo "*/30 * * * * root [ -x ${initdscript} ] && nice -1 ${initdscript} start 2>&1" >> ${cron_table2}
/etc/init.d/cron restart

initd=/etc/init.d/${app}
mv ${app} $initd
chown root:root $initd
chmod 755 $initd
update-rc.d -n ${app} defaults
update-rc.d ${app} defaults

faxlogs=/etc/logrotate.d/innovaphone-faxserver-logs
mv rsyslog/innovaphone-faxserver-logs $faxlogs
chown root:root $faxlogs
chmod 644 $faxlogs

faxwebdav="/var/www/innovaphone/webdav/faxserver"
if [ ! -d $faxwebdav ]; then
    mkdir $faxwebdav
    chown www-data:www-data $faxwebdav
    chmod 755 $faxwebdav
fi

# Create vmail group
if ! cat /etc/group | grep "vmail" &>/dev/null
then
    if ! groupadd -g 5000 vmail 2>/dev/null
    then
        echo "ERROR: $(date '+%Y-%m-%d %H:%M:%S') - linux group vmail could not be created"
        on_error
        exit 1
    fi
    echo "LOG: $(date '+%Y-%m-%d %H:%M:%S') - linux group vmail created"
fi

# Create vmail user
if ! cat /etc/passwd | grep "vmail" &>/dev/null
then
    if ! useradd -s /usr/sbin/nologin -u 5000 -g 5000 vmail 2>/dev/null
    then
        echo "ERROR: $(date '+%Y-%m-%d %H:%M:%S') - linux user vmail could not be created"
        on_error
        exit 1
    fi
    echo "LOG: $(date '+%Y-%m-%d %H:%M:%S') - linux user vmail created"
fi

# Create vhosts directory
vhosts_dir="/var/mail/vhosts"
if [ ! -d $vhosts_dir ]; then
    mkdir $vhosts_dir
	chown vmail:root $vhosts_dir
	chmod u=rwx,g=s,o= $vhosts_dir
	echo "LOG: $(date '+%Y-%m-%d %H:%M:%S') - $vhosts_dir created"
fi

# Create catchall mailbox directory
catchall_dir="/var/mail/vhosts/catchall.faxserver"
if [ ! -d $catchall_dir ]; then
    mkdir $catchall_dir
	chown vmail:root $catchall_dir
	chmod u=rwx,g=s,o= $catchall_dir
	echo "LOG: $(date '+%Y-%m-%d %H:%M:%S') - $catchall_dir created"
fi

postfix_dir=/etc/postfix
postfix_1=postfix/main.cf
postfix_2=postfix/master.cf
postfix_3=postfix/smtpd_command_filter
postfix_4=postfix/smtpd_recipient_restrictions.cf
postfix_5=postfix/transport_maps.cf
postfix_6=postfix/virtual_alias_maps_catchall.cf
postfix_7=postfix/virtual_alias_maps_authorized_hosts.cf
postfix_8=postfix/authorized_hosts.cf
chown root:root $postfix_1
chown root:root $postfix_2
chown root:root $postfix_3
chown root:root $postfix_4
chown root:root $postfix_5
chown root:root $postfix_6
chown root:root $postfix_7
chown root:root $postfix_8
chmod 644 $postfix_1
chmod 644 $postfix_2
chmod 644 $postfix_3
chmod 644 $postfix_4
chmod 644 $postfix_5
chmod 644 $postfix_6
chmod 644 $postfix_7
chmod 644 $postfix_8
mv $postfix_1 $postfix_dir/.
mv $postfix_2 $postfix_dir/.
mv $postfix_3 $postfix_dir/.
mv $postfix_4 $postfix_dir/.
mv $postfix_5 $postfix_dir/.
mv $postfix_6 $postfix_dir/.
mv $postfix_7 $postfix_dir/.
mv $postfix_8 $postfix_dir/.

dovecot_dir=/etc/dovecot
dovecot_1=dovecot/dovecot.conf
dovecot_2=dovecot/dovecot-sql.conf
chown root:root $dovecot_1
chown root:root $dovecot_2
chmod 644 $dovecot_1
chmod 644 $dovecot_2
mv $dovecot_1 $dovecot_dir/.
mv $dovecot_2 $dovecot_dir/.

sieve_skript=dovecot/.dovecot.sieve
chown vmail:root $sieve_skript
chmod u=rwx,g=s,o= $sieve_skript
mv $sieve_skript $catchall_dir/.

update-rc.d dovecot defaults
/etc/init.d/postfix restart
echo "LOG: $(date '+%Y-%m-%d %H:%M:%S') - Postfix restarted"
/etc/init.d/dovecot restart
echo "LOG: $(date '+%Y-%m-%d %H:%M:%S') - Dovecot started"

chmod -R 775 /var/www/innovaphone/apps/innovaphone-faxserver/covers

# restart rsyslog to (re)create the log files
/etc/init.d/rsyslog restart
# do not change "Installation was successful", it will be matched!
echo "LOG: $(date '+%Y-%m-%d %H:%M:%S') - The web server will be restarted a few seconds after the installation!"
echo "LOG: $(date '+%Y-%m-%d %H:%M:%S') - Installation was successful"
sleep 10s
php5-cgi /var/www/innovaphone/update_webserver_cfg.php

on_exit
exit 0
